![Python 3.8](https://img.shields.io/badge/python-3.8-green.svg)
[![license](https://img.shields.io/github/license/mashape/apistatus.svg?maxAge=2592000)](https://github.com/leonfrcom/ErroRCalcS/blob/master/LICENSE)

# Deputat
Einfaches graphisches Benutzer Interface (GUI) zur Vergabe von Schulstunden.
____
Aktuelle Version: 1.1.5
#### Changes in 1.1.5
- fixed requirement error for ```json```
#### Changes in 1.1.4
- added functionality to add/remove/edit subjects
- added default subjects-file ```./data/subjects.json```
#### Changes in 1.1.3
- added ```*.svg``` icons to ```sdist```
- data can now be exported as ```*.csv``` or ```*.xlsx```
- fixed ```import``` errors
- changed default data location to ```/home/user/deputat_data/data/```
- fixed ```FileNotFoundError``` for ```*.svg```
- fixed Windows specific bugs
- fixed MacOS import errors
- fixed find icons
____

# Installation und Starten von deputat
1. [Installiere python3](https://github.com/lfreist/deputat/blob/master/infos/install_python.md)
2. Installiere deputat über pythons packetmanager [PyPi](https://pypi.org/). Gebe dazu
in der Konsole ```python3 -m pip install deputat``` ein
3. Starte deputat über ```python3 -m deputat```
